/*
 * Archivo de cadenas traducibles generado por Glade.
 * Añada este archivo a su POTFILES.in de su proyecto.
 * NO lo compile como parte de su aplicación.
 */

gchar *s = N_("To select a time zone, click on one of the dots on the map");
gchar *s = N_("Time Zone:");
gchar *s = N_("*");
gchar *s = N_("Select the servers you wish to use for time synchronization.");
gchar *s = N_("*");
gchar *s = N_("window1");
gchar *s = N_("Please select the current date and time. You can also specify a time zone and a time server.");
gchar *s = N_("<span weight=\"bold\">Time Configuration</span>");
gchar *s = N_("_Time:");
gchar *s = N_("Time zone:");
gchar *s = N_(":");
gchar *s = N_(":");
gchar *s = N_("(unconfigured)");
gchar *s = N_("_Select Time Zone...");
gchar *s = N_("_Date:");
gchar *s = N_("S_ynchronize clock with Internet servers");
gchar *s = N_("Se_lect Servers...");
